#!/bin/zsh
# Script Version: 0.5
# Description: Aktualisiert das Open WebUI Repository und startet den Dienst neu

cd /srv/open-webui || exit 1

echo "[DEBUG] Working directory: $(pwd)"

# Sicherung nicht übergebener Änderungen
if [[ -n $(git status --porcelain) ]]; then
  echo "[DEBUG] Änderungen vorhanden – stash wird ausgeführt"
  git stash --all
else
  echo "[DEBUG] Keine lokalen Änderungen"
fi

# Repository synchronisieren
echo "[DEBUG] Repository wird aktualisiert"
git pull --rebase

# Änderungen zurückholen, falls gestasht
if git stash list | grep -q "WIP on"; then
  echo "[DEBUG] Änderungen werden wiederhergestellt"
  git stash pop
else
  echo "[DEBUG] Keine Änderungen zum Wiederherstellen"
fi

# Dienst neu starten und Status prüfen
systemctl restart openwebui.service
sleep 2
echo "[DEBUG] openwebui.service wurde erfolgreich neu gestartet"
systemctl status openwebui.service --no-pager

